<?php

namespace Litecms\BoardUser\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BoardUser\Models\BoardUser;

class BoardUserPolicy
{

    /**
     * Determine if the given user can view the board_user.
     *
     * @param UserPolicy $user
     * @param BoardUser $board_user
     *
     * @return bool
     */
    public function view(UserPolicy $user, BoardUser $board_user)
    {
        if ($user->canDo('board_user.board_user.view') && $user->isAdmin()) {
            return true;
        }

        return $board_user->user_id == user_id() && $board_user->user_type == user_type();
    }

    /**
     * Determine if the given user can create a board_user.
     *
     * @param UserPolicy $user
     * @param BoardUser $board_user
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('board_user.board_user.create');
    }

    /**
     * Determine if the given user can update the given board_user.
     *
     * @param UserPolicy $user
     * @param BoardUser $board_user
     *
     * @return bool
     */
    public function update(UserPolicy $user, BoardUser $board_user)
    {
        if ($user->canDo('board_user.board_user.edit') && $user->isAdmin()) {
            return true;
        }

        return $board_user->user_id == user_id() && $board_user->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given board_user.
     *
     * @param UserPolicy $user
     * @param BoardUser $board_user
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BoardUser $board_user)
    {
        return $board_user->user_id == user_id() && $board_user->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given board_user.
     *
     * @param UserPolicy $user
     * @param BoardUser $board_user
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BoardUser $board_user)
    {
        if ($user->canDo('board_user.board_user.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given board_user.
     *
     * @param UserPolicy $user
     * @param BoardUser $board_user
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BoardUser $board_user)
    {
        if ($user->canDo('board_user.board_user.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
